==> img0ch-2.1.9.tar.bz2: img0ch/_template/zeromin2/bbs_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/bbs_right_menu.cs" ?>

<div id="main">

<form id="bbsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post" onsubmit="return confirmIfRemove(this)">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
</div>

<h1>掲示板管理</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_update_index ?><div class="noticeSuccess" id="notify"><p>インデックスの更新を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_repair_upload_file_table ?><div class="noticeSuccess" id="notify"><p>アップロードデータを修復しました</p></div><?cs /if ?>
<?cs if:Done_bbs_update_subject ?><div class="noticeSuccess" id="notify"><p>サブジェクトファイルを更新しました</p></div><?cs /if ?>
<?cs if:Done_bbs_recreate_subject ?><div class="noticeSuccess" id="notify"><p>サブジェクトファイルを再生成しました</p></div><?cs /if ?>
<?cs if:Done_bbs_remove ?><div class="noticeSuccess" id="notify"><p>掲示板の削除を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_create ?><div class="noticeSuccess" id="notify"><p>掲示板の作成を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_update_bbsmenu ?><div class="noticeSuccess" id="notify"><p>掲示板のメニュー更新を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_repair_bbs_table ?><div class="noticeSuccess" id="notify"><p>掲示板情報の修復を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_load ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象の掲示板が選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" charset="UTF-8">
//<![CDATA[
function confirmIfRemove(element) {
    var methodName = jQuery( "select[@name='method']", this ).val();
    if (methodName == "remove") {
        if (!window.confirm("掲示板を削除すると二度と復活することが出来なくなります。\n"
            + "掲示板の削除を行いますか？")) {
            return false;
        }
    }
    return true;
}
//]]>
</script>

<p>
テーブル内のチェックボタンをクリックし、「操作内容」で決定。<br />
テーブル内のリンクをクリックすると各掲示板管理画面に移動します。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=create_form&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板の新規作成はこちらから行ってください</a>
</p>

<p>
<select name="method">
  <option value="load">掲示板一覧を表示</option>
  <option value="update_index">インデックスの更新</option>
  <option value="repair_upload_file_table">アップロードデータの修復</option>
  <option value="update_subject">サブジェクトの更新</option>
  <option value="recreate_subject">サブジェクトの再生成</option>
  <option value="remove">掲示板の削除</option>
  <option value="update_bbsmenu">掲示板メニュー更新</option>
  <option value="repair_bbs_table">掲示板情報修復</option>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>

</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'board' )" /></th>
    <th>掲示板名</th>
    <th>ディレクトリ名</th>
    <th>カテゴリ名</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><input type="checkbox" name="board" value="<?cs var:html_escape(item.id) ?>" /></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(item.id) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false" title="このリンクは<?cs var:item.name ?>の「スレッド整理」を参照します"><?cs var:item.name ?></a></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(item.id) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false" title="このリンクは<?cs var:item.name ?>の「インデックス」を参照します"><?cs var:html_escape(item.dir) ?></a></td>
    <td><?cs var:html_escape(item.cname) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="OK" value="load" />
<input type="hidden" name="NG" value="load" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.11.tar.bz2: img0ch/_template/zeromin2/bbs_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/bbs_right_menu.cs" ?>

<div id="main">

<form id="bbsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post" onsubmit="return confirmIfRemove(this)">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
</div>

<h1>掲示板管理</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_update_index ?><div class="noticeSuccess" id="notify"><p>インデックスの更新を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_repair_upload_file_table ?><div class="noticeSuccess" id="notify"><p>アップロードデータを修復しました</p></div><?cs /if ?>
<?cs if:Done_bbs_repair_tag_table ?><div class="noticeSuccess" id="notify"><p>タグデータを修復しました</p></div><?cs /if ?>
<?cs if:Done_bbs_update_subject ?><div class="noticeSuccess" id="notify"><p>サブジェクトファイルを更新しました</p></div><?cs /if ?>
<?cs if:Done_bbs_recreate_subject ?><div class="noticeSuccess" id="notify"><p>サブジェクトファイルを再生成しました</p></div><?cs /if ?>
<?cs if:Done_bbs_remove ?><div class="noticeSuccess" id="notify"><p>掲示板の削除を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_create ?><div class="noticeSuccess" id="notify"><p>掲示板の作成を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_update_bbsmenu ?><div class="noticeSuccess" id="notify"><p>掲示板のメニュー更新を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_repair_bbs_table ?><div class="noticeSuccess" id="notify"><p>掲示板情報の修復を行いました</p></div><?cs /if ?>
<?cs if:Done_bbs_load ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象の掲示板が選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" charset="UTF-8">
//<![CDATA[
function confirmIfRemove(element) {
    var methodName = jQuery( "select[@name='method']", this ).val();
    if (methodName == "remove") {
        if (!window.confirm("掲示板を削除すると二度と復活することが出来なくなります。\n"
            + "掲示板の削除を行いますか？")) {
            return false;
        }
    }
    return true;
}
//]]>
</script>

<p>
テーブル内のチェックボタンをクリックし、「操作内容」で決定。<br />
テーブル内のリンクをクリックすると各掲示板管理画面に移動します。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=create_form&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板の新規作成はこちらから行ってください</a>
</p>

<p>
<select name="method">
  <option value="load">掲示板一覧を表示</option>
  <option value="update_index">インデックスの更新</option>
  <option value="repair_upload_file_table">アップロードデータの修復</option>
  <option value="repair_tag_table">タグデータの修復</option>
  <option value="update_subject">サブジェクトの更新</option>
  <option value="recreate_subject">サブジェクトの再生成</option>
  <option value="remove">掲示板の削除</option>
  <option value="update_bbsmenu">掲示板メニュー更新</option>
  <option value="repair_bbs_table">掲示板情報修復</option>
</select>
<input type="submit" value="実行" />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>

</p>

<table class="simple">
  <thead>
  <tr>
    <th><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'board' )" /></th>
    <th>掲示板名</th>
    <th>ディレクトリ名</th>
    <th>カテゴリ名</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><input type="checkbox" name="board" value="<?cs var:html_escape(item.id) ?>" /></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(item.id) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false" title="このリンクは<?cs var:item.name ?>の「スレッド整理」を参照します"><?cs var:item.name ?></a></td>
    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(item.id) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false" title="このリンクは<?cs var:item.name ?>の「インデックス」を参照します"><?cs var:html_escape(item.dir) ?></a></td>
    <td><?cs var:html_escape(item.cname) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="OK" value="load" />
<input type="hidden" name="NG" value="load" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
